import type { Position, Editor as CodemirrorEditor } from 'codemirror';
import type { IColumn, IDataSource } from './config/mock.column';
export declare type RewriteType<T> = {
    -readonly [key in keyof T]: T[key];
};
export interface Variable {
    label: string;
    value: string;
    type: string;
    _value?: unknown;
}
export interface FunctionItem {
    type: string;
    name: string;
    description: string;
    useage?: string;
    example?: string | undefined;
}
export interface FunctionGroup {
    name: string;
    functions: FunctionItem[];
}
export interface GetEditorPosParams {
    value: string;
    index: number;
    ch: number;
    line: number;
    name: string;
    pos: Position;
    isRightFieldEnd: boolean;
}
export interface GetEditorPosReturns {
    range: Position[];
    ch: number;
}
export declare type ReplaceVariable = (editor: CodemirrorEditor, begin: Position, end: Position, val: Variable) => void;
export declare type InitLineTag = (editor: CodemirrorEditor, content: string, line: number, innerVariables?: Variable[]) => void;
export declare type InitDocTag = (editor: CodemirrorEditor, code: string, innerVariables?: Variable[]) => void;
export declare type FuzzySearchField = (fields: Variable[], inputValue: string) => Variable[];
export declare type FuzzySearchFunctions = (functionArray: FunctionGroup[], inputValue: string) => Array<{
    name: string;
    functions: FunctionItem[];
}>;
export declare type UseFormula = (value: string, dataSourceItem: {}) => string | string[] | undefined;
export declare type IsValidField = (input: string, fields: string[]) => boolean;
export declare type ReverseField = (input: string, fields: Variable[]) => string;
export declare type GetNearestIndex = (inputValue: string, extraSymbols?: string[]) => number;
export declare type GetFieldBlock = (inputValue: string, endIndex: number) => string;
export declare type GetCodeBlock = (inputValue: string, sign: string) => string;
export declare type IsValidFunction = (inputFunction: string) => string;
export declare type GetEditorPos = (P: GetEditorPosParams) => GetEditorPosReturns;
export declare type FilterFieldColumn = (inputArray: {
    label: string;
    value: string;
    type: string;
}[]) => Variable[];
export declare type FilterFormulaField = (T: IColumn[number]) => Variable;
export declare type ParseFullFieldData = (fields: Variable[], sourceData: IDataSource | any) => any;
export declare type ParseFieldData = (key: string, sourceData: IDataSource | any) => any[] | null;
export declare type ParseField = (c: IColumn) => Variable[];
export declare type ParseKeyReplaceField = (fields: string[], originalField: string, replacedFields: string[]) => string;
